$set 14 #main

$ #RCRequiresArg
# error: '-rc' ץϰɬפȤޤ\n
$ #DISPLAYRequiresArg
# error: '-display' ץϰɬפȤޤ\n
$ #WarnDisplaySet
# warning: Ķѿ 'DISPLAY' ǤޤǤ\n
$ #Usage
# Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
  -display <string>\t\t ǥץ쥤³.\n\
  -rc <string>\t\t\t Υ꥽ե.\n\
  -version\t\t\t Сɽƽλ.\n\
  -info\t\t\t\tdisplay some useful information.\n\
  -log <filename>\t\t\tlog output to file.\n\
  -help\t\t\t\t Υإפɽƽλ.\n\n
$ #CompileOptions
# ѥΥץ:\n\
  Debugging\t\t\t%s\n\
  Interlacing:\t\t\t%s\n\
  Shape:\t\t\t%s\n\
  Slit:\t\t\t\t%s\n\
  8bpp Ordered Dithering:\t%s\n\n
